module.exports = defineTest({
	description: 'includes effects in for-of loop (#870)'
});
